# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-25 08:21
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0008_auto_20191025_1640'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='report',
            options={'permissions': (('can_view_report', '\u53ef\u4ee5\u67e5\u770b\u62a5\u8868'), ('can_view_website_report', 'can_view_website_report'), ('can_view_user_report', 'can_view_user_report'), ('can_view_course_report', 'can_view_course_report'))},
        ),
    ]
