# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-25 08:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0007_auto_20191025_1453'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mentorscoreweek',
            options={'ordering': ['created_at'], 'permissions': (('view_mentorscoreweek', '\u53ef\u4ee5\u67e5\u770b\u5168\u90e8\u52a9\u6559\u5206\u6570'), ('change_score1', '\u53ef\u4ee5\u4fee\u6539\u5206\u65701'), ('change_score2', '\u53ef\u4ee5\u4fee\u6539\u5206\u65702'), ('change_score3', '\u53ef\u4ee5\u4fee\u6539\u5206\u65703'), ('change_score4', '\u53ef\u4ee5\u4fee\u6539\u5206\u65704'))},
        ),
    ]
