# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-25 06:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0006_auto_20190927_1449'),
    ]

    operations = [
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score1',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65701'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score2',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65702'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score3',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65703'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score4',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65704'),
        ),
    ]
