# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-27 06:49
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0005_auto_20190830_1413'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mentorscoreweek',
            options={'ordering': ['created_at'], 'permissions': (('view_mentorscoreweek', '\u53ef\u4ee5\u67e5\u770b\u5168\u90e8\u52a9\u6559\u5206\u6570'),)},
        ),
        migrations.AlterModelOptions(
            name='report',
            options={'permissions': (('can_view_report', '\u53ef\u4ee5\u67e5\u770b\u62a5\u8868'),)},
        ),
    ]
